@@ -14,7 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from gettext import gettext as _
-import datetime
+from datetime import datetime, timedelta
 import locale
 
 
@@ -26,8 +26,8 @@ def money(value):
 
 
 def readable_date(date: datetime) -> str:
-    today = datetime.datetime.today()
-    yesterday = today - datetime.timedelta(days=1)
+    today = datetime.today()
+    yesterday = today - timedelta(days=1)
     delta = today - date
 
     if date.date() == today.date():
@@ -35,8 +35,8 @@ def readable_date(date: datetime) -> str:
     elif date.date() == yesterday.date():
         date_str = _("Yesterday")
     elif delta.days < 0:
-        date_str = _("Open Booking Date:") + ' ' + date.strftime('%Y-%m-%d')
+        date_str = _("Open Booking Date:") + " " + date.strftime("%Y-%m-%d")
     else:
-        date_str = date.strftime('%A, %B %-d')
+        date_str = date.strftime("%A, %B %-d")
 
     return date_str
