@@ -14,13 +14,13 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import annotations
-from gettext import gettext as _
+from typing import Any
 import logging
 from gi.repository import Adw, Gio, Gtk, GLib
 from saldo.widgets.clients import Clients
 from saldo.widgets.account_row import AccountRow
 from saldo.widgets.transaction_row import TransactionRow
-from saldo.widgets.transaction_details import TransactionDetails # noqa
+from saldo.widgets.transaction_details import TransactionDetails  # noqa
 from saldo.backend.backend import BankingBackend
 from saldo.backend.helper import money
 from saldo.backend.helper import readable_date
@@ -33,9 +33,16 @@ def _transaction_listbox_placeholder():
     return status_page
 
 
-@Gtk.Template(resource_path='/org/tabos/saldo/ui/unlocked_page.ui')
+def _statistics_listbox_placeholder():
+    status_page = Adw.StatusPage()
+    status_page.set_icon_name("edit-find-symbolic")
+    status_page.set_title("No Statistic Available")
+    return status_page
+
+
+@Gtk.Template(resource_path="/org/tabos/saldo/ui/unlocked_page.ui")
 class UnlockedPage(Adw.Bin):
-    __gtype_name__ = 'UnlockedPage'
+    __gtype_name__ = "UnlockedPage"
 
     _content_box = Gtk.Template.Child()
     _detail_window = Gtk.Template.Child()
@@ -72,25 +79,29 @@ class UnlockedPage(Adw.Bin):
         self._transaction_listbox.set_filter_func(self._transaction_filter)
         self._transaction_listbox.add_css_class("background")
 
+        self._statistic_listbox.set_header_func(self._statistic_header)
+        self._statistic_listbox.set_placeholder(_statistics_listbox_placeholder())
         self._statistic_listbox.set_sort_func(self._statistic_sort)
         self._statistic_listbox.set_filter_func(self._statistic_filter)
+        self._statistic_listbox.add_css_class("background")
 
-        self.stack.connect('notify::visible-child-name', self._on_stack_notify_visible_child_name)
+        self.stack.connect(
+            "notify::visible-child-name", self._on_stack_notify_visible_child_name
+        )
 
         self._search_bar.connect_entry(self._search_entry)
         self._search_bar.set_key_capture_widget(self.window)
 
         controller = Gtk.EventControllerKey()
-        controller.connect('key-pressed', self._on_key_pressed)
+        controller.connect("key-pressed", self._on_key_pressed)
         self.add_controller(controller)
 
-        self._backend.connect('accounts_refreshed', self._on_accounts_refreshed)
-        self._backend.connect('notify::loading', self._on_loading_changed)
+        self._backend.connect("accounts_refreshed", self._on_accounts_refreshed)
+        self._backend.connect("notify::loading", self._on_loading_changed)
 
         if not backend.clients:
-            clients = Clients(self._backend, use_header_bar=True)
-            clients.set_transient_for(self.window)
-            clients.present()
+            clients = Clients(self._backend)
+            clients.present(self.window)
         else:
             self._populate_data()
 
@@ -99,7 +110,7 @@ class UnlockedPage(Adw.Bin):
     def _on_stack_notify_visible_child_name(self, stack, param):
         self.window.start_lock_timer()
 
-        if stack.get_visible_child_name() == 'statistic':
+        if stack.get_visible_child_name() == "statistic":
             self.__statistic_switch = False
             self.__search_text = None
             self._search_entry.set_text("")
@@ -111,9 +122,9 @@ class UnlockedPage(Adw.Bin):
     def _on_loading_changed(self, backend, param):
         if backend.props.loading:
             self.refresh_spinner.start()
-            self._refresh_spinner_stack.set_visible_child_name('spinner')
+            self._refresh_spinner_stack.set_visible_child_name("spinner")
         else:
-            self._refresh_spinner_stack.set_visible_child_name('image')
+            self._refresh_spinner_stack.set_visible_child_name("image")
             self.refresh_spinner.stop()
 
     def _on_key_pressed(self, event, keyval, keycode, state):  # pylint: disable=unused-argument
@@ -124,13 +135,16 @@ class UnlockedPage(Adw.Bin):
     def do_dispose(self):  # pylint: disable=arguments-differ
         self._search_entry.set_key_capture_widget(None)
 
-    def do_realize(self):    # pylint: disable=arguments-differ
+    def do_realize(self):  # pylint: disable=arguments-differ
         Gtk.Widget.do_realize(self)
         self._account_listbox.grab_focus()
 
-    def update_account_header(self, row: Gtk.ListBoxRow, before: Gtk.ListBoxRow) -> None:
+    def update_account_header(
+        self, row: Gtk.ListBoxRow, before: Gtk.ListBoxRow
+    ) -> None:
         if before is None:
             vbox = Gtk.Box()
+            vbox.set_margin_bottom(6)
             vbox.add_css_class("background")
             vbox.set_orientation(Gtk.Orientation.VERTICAL)
 
@@ -162,7 +176,9 @@ class UnlockedPage(Adw.Bin):
         else:
             row.set_header(None)
 
-    def update_transaction_header(self, row: Gtk.ListBoxRow, before: Gtk.ListBoxRow) -> None:
+    def update_transaction_header(
+        self, row: Gtk.ListBoxRow, before: Gtk.ListBoxRow
+    ) -> None:
         if self._last_transaction_added != row.transaction.date or before is None:
             vbox = Gtk.Box()
             vbox.add_css_class("background")
@@ -211,16 +227,6 @@ class UnlockedPage(Adw.Bin):
             hbox.set_margin_top(6)
             hbox.set_margin_bottom(6)
 
-            update = Gtk.Label()
-            update.set_hexpand(True)
-            update.set_text(_("Income"))
-            update.set_halign(Gtk.Align.CENTER)
-            update.add_css_class("dim-label")
-            hbox.append(update)
-
-            separator = Gtk.Separator()
-            vbox.append(separator)
-
             row.set_header(vbox)
         else:
             row.set_header(None)
@@ -264,7 +270,6 @@ class UnlockedPage(Adw.Bin):
         self._account_listbox.invalidate_headers()
 
     def _on_accounts_refreshed(self, backend: BankingBackend) -> None:
-
         GLib.idle_add(self._refreshed_idle)
 
     def _refreshed_idle(self):
@@ -312,62 +317,77 @@ class UnlockedPage(Adw.Bin):
     def _add_statistic_row(self, listbox, dict, debit_total, credit_total):
         row = Adw.ActionRow()
         row.set_activatable(True)
-        row.connect('activated', self._on_statistic_listbox_row_activated)
-        row.set_title(dict['name'])
+        row.add_css_class("card")
+        row.set_margin_top(6)
+        row.set_margin_bottom(6)
+        row.connect("activated", self._on_statistic_listbox_row_activated)
+        row.set_title(dict["name"])
 
-        if dict['amount'] < 0:
-            percent = -round(dict['amount'] / credit_total * 100, 1) if credit_total != 0 else 0
+        if dict["amount"] < 0:
+            percent = (
+                -round(dict["amount"] / credit_total * 100, 1)
+                if credit_total != 0
+                else 0
+            )
         else:
-            percent = round(dict['amount'] / debit_total * 100, 1) if debit_total != 0 else 0
+            percent = (
+                round(dict["amount"] / debit_total * 100, 1) if debit_total != 0 else 0
+            )
 
         row.set_subtitle(f"{percent}%")
 
         avatar = Adw.Avatar()
         avatar.set_size(32)
-        self._backend.category_set_avatar_by_category_name(avatar, dict['internal_name'])
+        self._backend.category_set_avatar_by_category_name(avatar, dict["name"])
         row.add_prefix(avatar)
 
-        amount = money(dict['amount'])
+        amount = money(dict["amount"])
         amount_label = Gtk.Label()
         amount_label.set_text(amount + " " + "EUR")  # self._transaction.currency)
 
         row.add_suffix(amount_label)
-        if dict['amount'] >= 0.0:
-            amount_label.add_css_class('success')
+        if dict["amount"] >= 0.0:
+            amount_label.add_css_class("success")
         else:
-            amount_label.add_css_class('error')
+            amount_label.add_css_class("error")
 
         listbox.append(row)
 
     def _update_statistic(self) -> None:
         self._clear_listbox(self._statistic_listbox)
 
-        dict = {}
+        dct: dict[str, Any] = {}
         for transaction in self.__active_account_row.transactions:
             category = self._backend.category_get_name(transaction.transaction.name)
 
-            if category not in dict:
-                dict[category] = {}
-                dict[category]['name'] = category
-                dict[category]['internal_name'] = self._backend.category_get_internal_name(transaction.transaction.name)
-                dict[category]['amount'] = 0.0
+            if category not in dct:
+                dct[category] = {}
+                dct[category]["name"] = category
+                dct[category]["internal_name"] = (
+                    self._backend.category_get_internal_name(
+                        transaction.transaction.name
+                    )
+                )
+                dct[category]["amount"] = 0.0
 
-            dict[category]['amount'] += transaction.transaction.amount
+            dct[category]["amount"] += transaction.transaction.amount
 
         debit_total = 0.0
         credit_total = 0.0
 
-        for entry in dict:
-            if dict[entry]['amount'] < 0:
-                credit_total += dict[entry]['amount']
+        for entry in dct:
+            if dct[entry]["amount"] < 0:
+                credit_total += dct[entry]["amount"]
             else:
-                debit_total += dict[entry]['amount']
+                debit_total += dct[entry]["amount"]
 
-        for entry in dict:
-            self._add_statistic_row(self._statistic_listbox, dict[entry], debit_total, credit_total)
+        for entry in dct:
+            self._add_statistic_row(
+                self._statistic_listbox, dct[entry], debit_total, credit_total
+            )
 
     @Gtk.Template.Callback()
-    def _on_account_listbox_row_selected(self, _, row: AccountRow) -> None:
+    def _on_account_listbox_row_selected(self, _: Gtk.ListBox, row: AccountRow) -> None:
         self.window.start_lock_timer()
 
         self.__active_account_row = row
@@ -378,18 +398,20 @@ class UnlockedPage(Adw.Bin):
         self._content_box.set_visible_child(self._detail_window)
 
     @Gtk.Template.Callback()
-    def _on_back_button_clicked(self, _):
+    def _on_back_button_clicked(self, _: Gtk.Widget) -> None:
         self.window.start_lock_timer()
         self._content_box.set_visible_child(self._sidebar)
 
     @Gtk.Template.Callback()
-    def _on_refresh_button_clicked(self, _):
+    def _on_refresh_button_clicked(self, _: Gtk.Widget) -> None:
         self.window.start_lock_timer()
 
         self.window.backend.refresh_accounts()
 
     @Gtk.Template.Callback()
-    def _on_transaction_listbox_row_selected(self, _, row: TransactionRow):
+    def _on_transaction_listbox_row_selected(
+        self, _: Gtk.Widget, row: TransactionRow
+    ) -> None:
         self.window.start_lock_timer()
 
         if not self._details_bin.props.child:
@@ -400,16 +422,16 @@ class UnlockedPage(Adw.Bin):
         details.set_transaction(row.transaction)
         self.subpage_leaflet.navigate(Adw.NavigationDirection.FORWARD)
 
-    def _on_statistic_listbox_row_activated(self, row: Adw.ActionRow):
+    def _on_statistic_listbox_row_activated(self, row: Adw.ActionRow) -> None:
         self.window.start_lock_timer()
 
         self._search_entry.set_text(row.get_title())
         self._search_bar.set_search_mode(True)
         self.__statistic_switch = True
-        self.stack.set_visible_child_name('transactions')
+        self.stack.set_visible_child_name("transactions")
 
     @Gtk.Template.Callback()
-    def _on_search_changed(self, search_entry):  # pylint: disable=unused-argument
+    def _on_search_changed(self, search_entry: Gtk.Widget) -> None:  # pylint: disable=unused-argument
         self.window.start_lock_timer()
 
         if self.stack.get_visible_child_name() == "transactions":
@@ -450,7 +472,10 @@ class UnlockedPage(Adw.Bin):
             ret = search_text in row.transaction.posting_text.lower()
 
         if not ret:
-            ret = search_text in self._backend.category_get_name(row.transaction.name).lower()
+            ret = (
+                search_text
+                in self._backend.category_get_name(row.transaction.name).lower()
+            )
 
         return ret
 
@@ -505,13 +530,9 @@ class UnlockedPage(Adw.Bin):
             self._on_session_lock,
         )
 
-    def _on_session_lock(self,
-                         _connection,
-                         _unique_name,
-                         _object_path,
-                         _interface,
-                         _signal,
-                         state):
+    def _on_session_lock(
+        self, _connection, _unique_name, _object_path, _interface, _signal, state
+    ):
         if state[0]:
             self.window.view = self.window.View.LOCKED
 
