@@ -16,9 +16,9 @@
 from gi.repository import Adw, Gtk
 
 
-@Gtk.Template(resource_path='/org/tabos/saldo/ui/welcome_page.ui')
+@Gtk.Template(resource_path="/org/tabos/saldo/ui/welcome_page.ui")
 class WelcomePage(Adw.Bin):
-    __gtype_name__ = 'WelcomePage'
+    __gtype_name__ = "WelcomePage"
 
     _create_safe_button = Gtk.Template.Child()
 
